==> nextcloud-20.0.12.tgz: nextcloud/apps/federatedfilesharing/l10n/hu.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Hozzáadja a(z) {name} távoli megosztást innen: {owner}@{remote}?",
    "Remote share" : "Távoli megosztás",
    "Remote share password" : "Jelszó a távoli megosztáshoz",
    "Cancel" : "Mégse",
    "Add remote share" : "Távoli megosztás hozzáadása",
    "Copy" : "Másolás",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "A másoláshoz nyomjon ⌘-C-t.",
    "Press Ctrl-C to copy." : "A másoláshoz nyomjon Ctrl-C-t.",
    "Invalid Federated Cloud ID" : "Érvénytelen föderált felhőazonosító",
    "Server to server sharing is not enabled on this server" : "A kiszolgálók közötti megosztás nincs engedélyezve ezen a kiszolgálón",
    "Couldn't establish a federated share." : "A föderált megosztás nem hozható létre.",
    "Couldn't establish a federated share, maybe the password was wrong." : "A föderált megosztás nem hozható létre, lehet hogy a jelszó hibás.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Föderált megosztási kérés elküldve, kapni fog egy meghívót. Ellenőrizze az értesítéseit.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "A föderált megosztás nem hozható létre, úgy tűnik, hogy a föderálandó kiszolgáló túl régi. (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Nem küldhet föderált csoportmegosztást erről a kiszolgálóról.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "%1$s megosztása sikertelen, mert már meg van osztva %2$s felhasználóval",
    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet föderált megosztást létrehozni",
    "Federated shares require read permissions" : "Az egyesített megosztásoknak szükséges olvasási jogosultság",
    "File is already shared with %s" : "A fájl már meg van osztva vele: %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "A(z) %1$s megosztása sikertelen, a(z) %2$s nem található, talán a kiszolgáló jelenleg nem érhető el vagy önaláírt tanúsítványt használ.",
    "Could not find share" : "A megosztás nem található",
    "Federated sharing" : "Föderált megosztás",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "A(z) „%3$s” fogadva távoli megosztásként innen: %4$s (%1$s) (%5$s nevében (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Kapott egy távoli megosztást: {share}, innen: {user} ({behalf} nevében)",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Kapott egy távoli megosztást: „%3$s”, innen: %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Kapott egy távoli megosztást: {share}, innen: {user}",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Ossza meg velem a #Nextcloud föderált felhőazonosítóm segítségével, lásd %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Ossza meg velem a #Nextcloud föderált felhőazonosítóm segítségével ",
    "Sharing" : "Megosztás",
    "Federated file sharing" : "Föderált fájlmegosztás",
    "Provide federated file sharing across servers" : "Föderált fájlmegosztás biztosítása a kiszolgálók között",
    "Federated Cloud Sharing" : "Föderált felhőmegosztás",
    "Open documentation" : "Dokumentáció megnyitása",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Engedélyezze a szerveren lévő felhasználóknak, hogy megosztásokat küldjenek más szerverekre (ez az opció lehetővé teszi a WebDAV hozzáférését a nyilvános megosztásokhoz is)",
    "Allow users on this server to receive shares from other servers" : "Engedélyezze ezen kiszolgáló felhasználóinak, hogy megosztásokat fogadjanak más kiszolgálóktól",
    "Allow users on this server to send shares to groups on other servers" : "Engedélyezze ezen kiszolgáló felhasználóinak, hogy megosztásokat küldjenek más kiszolgálók csoportjainak",
    "Allow users on this server to receive group shares from other servers" : "Engedélyezi ezen kiszolgáló felhasználóinak, hogy csoportmegosztásokat fogadjanak más kiszolgálóktól",
    "Search global and public address book for users" : "Felhasználók keresése a globális és a nyilvános címjegyzékben",
    "Allow users to publish their data to a global and public address book" : "A felhasználók közzétehetik az adataikat a globális és nyilvános címjegyzékben",
    "Federated Cloud" : "Föderált felhő",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Bármelyik Nextcloud-kiszolgálót vagy egyéb Open Cloud Mesh-kompatibilis (OCM) kiszolgálót és szolgáltatást használó felhasználóval megoszthatja adatait. Csak tegye a föderált felhőazonosítóját a megosztási párbeszédablakba. Hasonlóan néz ki: person@cloud.example.com",
    "Your Federated Cloud ID:" : "Az Ön föderált felhőazonosítója:",
    "Share it so your friends can share files with you:" : "Ossza meg, hogy a barátai is oszthassanak meg Önnel fájlokat:",
    "Add to your website" : "Adja hozzá saját weboldalához",
    "Share with me via Nextcloud" : "Ossza meg velem a Nextcloudon keresztül",
    "HTML Code:" : "HTML-kód:",
    "Adjust how people can share between servers." : "Az emberek kiszolgálók közötti megosztásának beállítása."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.13.tgz: nextcloud/apps/federatedfilesharing/l10n/hu.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Hozzáadja a(z) {name} távoli megosztást innen: {owner}@{remote}?",
    "Remote share" : "Távoli megosztás",
    "Remote share password" : "Jelszó a távoli megosztáshoz",
    "Cancel" : "Mégse",
    "Add remote share" : "Távoli megosztás hozzáadása",
    "Copy" : "Másolás",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "A másoláshoz nyomjon ⌘-C-t.",
    "Press Ctrl-C to copy." : "A másoláshoz nyomjon Ctrl-C-t.",
    "Invalid Federated Cloud ID" : "Érvénytelen föderált felhőazonosító",
    "Server to server sharing is not enabled on this server" : "A kiszolgálók közötti megosztás nincs engedélyezve ezen a kiszolgálón",
    "Couldn't establish a federated share." : "A föderált megosztás nem hozható létre.",
    "Couldn't establish a federated share, maybe the password was wrong." : "A föderált megosztás nem hozható létre, lehet hogy a jelszó hibás.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Föderált megosztási kérés elküldve, kapni fog egy meghívót. Ellenőrizze az értesítéseit.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "A föderált megosztás nem hozható létre, úgy tűnik, hogy a föderálandó kiszolgáló túl régi. (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Nem küldhet föderált csoportmegosztást erről a kiszolgálóról.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "A(z) %1$s megosztása sikertelen, mert már meg van osztva %2$s felhasználóval",
    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet föderált megosztást létrehozni",
    "Federated shares require read permissions" : "A föderált megosztásokhoz olvasási jogosultság szükséges",
    "File is already shared with %s" : "A fájl már meg van osztva vele: %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "A(z) %1$s megosztása sikertelen, a(z) %2$s nem található, talán a kiszolgáló jelenleg nem érhető el vagy önaláírt tanúsítványt használ.",
    "Could not find share" : "A megosztás nem található",
    "Federated sharing" : "Föderált megosztás",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "A(z) „%3$s” fogadva távoli megosztásként innen: %4$s (%1$s) (%5$s nevében (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Kapott egy távoli megosztást: {share}, innen: {user} ({behalf} nevében)",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Kapott egy távoli megosztást: „%3$s”, innen: %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Kapott egy távoli megosztást: {share}, innen: {user}",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Ossza meg velem a #Nextcloud föderált felhőazonosítóm segítségével, lásd %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Ossza meg velem a #Nextcloud föderált felhőazonosítóm segítségével ",
    "Sharing" : "Megosztás",
    "Federated file sharing" : "Föderált fájlmegosztás",
    "Provide federated file sharing across servers" : "Föderált fájlmegosztás biztosítása a kiszolgálók között",
    "Federated Cloud Sharing" : "Föderált felhőmegosztás",
    "Open documentation" : "Dokumentáció megnyitása",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Állítsa be, hogy az emberek hogyan oszthatnak meg kiszolgálók között. Ebbe beleértendők a kiszolgálón lévő felhasználók közti megosztások és a föderált megosztások is.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Engedélyezze a kiszolgálón lévő felhasználóknak, hogy megosztásokat küldjenek más kiszolgálóknak (ez a lehetőség lehetővé teszi a nyilvános megosztások WebDAV hozzáférését is)",
    "Allow users on this server to receive shares from other servers" : "Engedélyezze ezen kiszolgáló felhasználóinak, hogy megosztásokat fogadjanak más kiszolgálóktól",
    "Allow users on this server to send shares to groups on other servers" : "Engedélyezze ezen kiszolgáló felhasználóinak, hogy megosztásokat küldjenek más kiszolgálók csoportjainak",
    "Allow users on this server to receive group shares from other servers" : "Engedélyezi ezen kiszolgáló felhasználóinak, hogy csoportmegosztásokat fogadjanak más kiszolgálóktól",
    "Search global and public address book for users" : "Felhasználók keresése a globális és a nyilvános címjegyzékben",
    "Allow users to publish their data to a global and public address book" : "A felhasználók közzétehetik az adataikat a globális és nyilvános címjegyzékben",
    "Federated Cloud" : "Föderált felhő",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Bármelyik Nextcloud-kiszolgálót vagy egyéb Open Cloud Mesh-kompatibilis (OCM) kiszolgálót és szolgáltatást használó felhasználóval megoszthatja adatait. Csak tegye a föderált felhőazonosítóját a megosztási párbeszédablakba. Hasonlóan néz ki: person@cloud.example.com",
    "Your Federated Cloud ID:" : "Az Ön föderált felhőazonosítója:",
    "Share it so your friends can share files with you:" : "Ossza meg, hogy a barátai is oszthassanak meg Önnel fájlokat:",
    "Add to your website" : "Adja hozzá saját weboldalához",
    "Share with me via Nextcloud" : "Ossza meg velem a Nextcloudon keresztül",
    "HTML Code:" : "HTML-kód:",
    "Adjust how people can share between servers." : "Az emberek kiszolgálók közötti megosztásának beállítása."
},
"nplurals=2; plural=(n != 1);");
